Monty Python's Flying Circus: Just the Words - Episode 17

# Episode Seventeen

Architect sketch
How to give up being a Mason
Motor insurance sketch
'The Bishop'
Living room on pavement
Poets
A choice of viewing
Chemist sketch
Words not to be used again
After-shave
Vox pops on aftershave
Police Constable Pan-Am

Colour code: John Cleese - Michael Palin - Eric Idle - Graham Chapman - Terry Jones - Terry Gilliam - Carol Cleveland

| Opens with animated item (the Butterfly). The announcer at a desk with propellors rise into view.
Announcer | And now for something completely different.
It's Man | It's...
| Animated titles.
Announcer | (and CAPTION:) 'THE BBC WOULD LIKE TO APOLOGIZE FOR THE NEXT ANNOUNCEMENT'
| Cut to a group of Gumbys, all with rolled-up trousers and knotted handkerchiefs on their heads, attempting to shout in unison and failing miserably.
Gumbys | Hello, and welcome to the show. Without more ado, the first item is a sketch about architects, called The Architects Sketch...The Architects Sketch...The Architects Sketch...(ad the sketch fails to start they point up at a nearby building) Up there!...Up there!...Up there!:..
| The camera pans to a window in the building. Cut to the office inside, where a board meeting is taking place. The Chairman is Mr Tid.
Mr Tid | Gentlemen, we have two basic suggestions for the design of this...(he is distracted by the two Gumbys still shouting)... Gentlemen, we have two basic suggestions for the design of this...(shouts out of window at the gumbys) Shut up! Gentlemen, we have two basic suggestions...(but the gumbys is still shouting 'Architects Sketch'; he throws a bucket of water over them; they subside, damply) Gentlemen, we have two basic suggestions for the design of this for the design of this residential block, and I thought it best that the architects themselves came in to explain the advantages of both designs. (knock at door) That must be the first architect noow. (Mr Wiggin comes in) Ah, yes - it's Mr Wiggin of Ironside and Malone.
| Wiggin walks to the table on which his model stand.
Mr Wiggin | Good morning, gentlemen. This is a twelwe-storey block combining classical neo-Georgian features with the efficiency of modern techniques. The tenants arrive in the entrance hall here, and are carried along the corridor on a conveyor belt in extreme comfort and past murals depicting Mediterranean scenes, towards the rotating knives. The last twenty feet of the corridor are heavily soundproofed. The blood pours down these chutes and the mangled flesh slurps into these...
First City Gent | Excuse me....
Mr Wiggin | Hm?
First City Gent | Did you say knives?
Mr Wiggin | Rotating knives, yes.
Second City Gent | Are you proposing to slaughter our tenants?
Mr Wiggin | Does that not fit in with your plans?
First City Gent | No, it does not. We asked for a simple block of flats.
Mr Wiggin | Oh, I see. I hadn't correctly divined your attitude towards your tenants. You see I mainly design slaughter houses. Yes, pity. Mind you, this is a real beaut. I mean, none of your blood caked on the walls and flesh flying out of the windows, inconveniencing the passers-by with this one. I mean, my life has been building up to this.
Second City Gent | Yes, and well done, but we want a block of flats.
Mr Wiggin | May I ask you to reconsider. I mean, you wouldn't regret it. Think of the tourist trade.
First City Gent | No, no, it's just that we wanted a block of flats, not an abattoir.
Mr Wiggin | Yes, well, of course, this is just the sort blinkered philistine pig ignorance I've come to expect from you non-creative garbage. You sit there on your loathsome, spotty behinds squeezing blackheads, not caring a tinker's cuss about the struggling artist. (shouting) You excrement! You lousy hypocritical whining toadies with your lousy colour TV sets and your Tony Jacklin golf clubs and your bleeding masonic handshakes! You wouldn't let me join, would you, you blackballing bastards. Well I wouldn't become a freemason now if you went down on your lousy, stinking, purulent knees and begged me.
Second City Gent | Well, we're sorry you feel like that but we, er, did want a block of flats. Nice though the abattoir is.
Mr Wiggin | Oh (blows raspberry) the abattoir, that's not important. But if any of you could put in a word for me I'd love to be a freemason. Freemasonry opens doors. I mean, I was...I was a bit on edge just now, but if I were a mason I'd sit at the back and not get in anyone's way.
First City Gent | Thank you.
Mr Wiggin | I've got a second-hand apron.
Second City Gent | Thank you.
Mr Wiggin | (going to door but stopping) I nearly got in at Hendon.
First City Gent | Thank you.
| Mr Wiggin leaves and the familiar figure of Mr Tid comes forward.
Mr Tid | I'm sorry about that, gentlemen. The second architect is Mr Leavey of Wymis and Dibble.
| Mr Leavey comes in and goes to his model.
Mr Leavey | Good morning gentlemen. This is a scale model of the block. There are twenty-eight storeys, with two hundred and eighty modern apartments. There are three main lifts and two service lifts. Access would be from Dibbingley Road. (the model falls over, and he quickly puts it upright) The structure is built on a central pillar system (the model falls over again) with (he puts model upright and holds onto it) cantilevered floors in pre-stressed steel and concrete. The dividing walls on each floor section are fixed by recessed magnalium flanged grooves. (the model partly collapses, the bottom ten floors giving way) By avoiding wood and timber derivatives and all other flammables (the model is smoking and flames are seen) we have almost totally removed the risk of...
| SUPERIMPOSED CAPTION: 'SATIRE'
Mr Leavey | Quite frankly, I think the central pillar system may need strengthening a bit.
Second City Gent | Isn't that going to put the cost up?
Mr Leavey | It might.
Second City Gent | Well, I don't know whether I'd worry about strengthening that much. After all, they're not meant to be luxury flats.
First City Gent | I quite agree. I mean, providing the tenants are of light build and relatively sedentary and er, given a spot of good weather, I think we're on to a winner here.
Mr Leavey | Thank you.
| The model explodes.
Second City Gent | Quite agree. Quite agree.
Mr Leavey | Thank you very much. Thank you. (he shakes hands with them in an extraordinary way)
Mr Wiggin | (at door) It opens doors, I'm telling you.
Voice Over | Let's have a look at that handshake again in slow motion.
| CAPTION: 'BBC TV ACTION REPLAY' They do the handshake again, only slowly.
First Voice Over | What other ways are there of recognizing a mason?
| Shot from camera concealed in a car so we get reactions of passers-by. A busy city street - i.e. Threadneedle Street. In amongst the throng four city gents are leaping along with their trousers round their ankles. They are wearing bowler hats and pinstripes. Another city street or another part of the same street. Two city gents, with trousers rolled up to the knee, approach each other and go into the most extraordinary handshake which involves rolling on the floor etc.
Second Voice Over | Having once identified a mason immediate steps must be taken to isolate him from the general public. Having accomplished that it is now possible to cure him of these unfortunate masonic tendencies through the use of behavioural psychotherapy. (we see a cartoon city gent locked into a cell) In this treatment the patient is rewarded for the correct response and punished for the wrong one. Let us begin. Would you like to give up being a mason? Think carefully. Think. Think.
Cartoon City Gent | No.
| A large hammer attacks the city gent.
Voice Over | No? That's wrong! Wrong! Wrong! Wrong! No! No! No! Bad! Bad!
| CAPTION: 'AN APOLOGY'
Announcer | The BBC would like to apologize for the following announcement.
| Pull out from caption to reveal that it is not a caption after all but a huge twenty-foot-square poster on a hoarding on the side of the road. After we pull out we hear the shuffling of many feet and grunting. A group of Gumbys shuffle into extreme left edge of frame. They do not move any futher into the picture. After a bit of humming and harring:
Gumbys | Oh! And the next item is called 'Insurance Sketch'. 'Insurance Sketch'. 'Insurance Sketch'...
| Cut to Mr Devious's insurance office. Devious and a man are sitting there.
Devious | What do you want?
| SUPERIMPOSED CAPTION: 'STRAIGHT MAN'
Man | Well I've come about your special fully comprehensive motor insurance policy offer...
Devious | What was that?
Man | Fully comprehensive motor insurance for one-and-eightpence.
Devious | Oh, oh, yes...yeah well, unfortunately, guv, that offer's no longer valid. You see, it turned out not to be commercially viable, so we now have a totally new offer...
Man | What's that?
Devious | A nude lady.
Man | A nude lady?
Devious | Yes. You get a nude lady with a fully comprehensive motor insurance. If you just want third party she has to keep her bra on, and if it's just theft...
Man | No, no, I don't really want that, Mr er...Mr...
Devious | Devious.
Man | Mr Devious. I just want to know what it would cost me to have a fully comprehensive inurance on a 1970 Aston Martin.
Devious | Aston Martin?
Man | Yes.
Devious | (quickly) Five hundred quid.
Man | Five hundred quid?
Devious | Forty quid.
Man | Forty quid?
Devious | Forty quid and a nude lady.
Man | No, no, I'm not interested in a nude lady.
Devious | Dirty books?
Man | No, no, look, I'm not interested in any af that. (superimposed 'STRAIGHT MAN' caption again) I just want to know what it would cost me to have a fully comprehensive insurance on a 1970 Aston Martin. Can you please qoute me your price.
| Cut to outside the door of the office. A vicar stands there.
Vicar | Knock knock.
| Cut to inside office.
Devious | Who's there
| Cut to outside.
Vicar | The Reverend...
| Cut to inside.
Devious | The Reverend who?
Vicar | The reverend Morrison.
| CAPTION: 'ANOTHER STRAIGHT MAN' Cut to inside.
Devious | Oh, come in.
| The vicar enters.
Devious | Now then, vic. What's the trouble?
Vicar | Well, it's about this letter you sent me.
Man | Excuse me, do I have any more lines?
Devious | I don't know, mush, I'll have to look in the script...(he gets script out of drawer) Where are we? Show 8. Are you 'man?
Man | Yeah.
Devious | No...no, you're finished.
Man | Well, I'll be off then. (he leaves)
Devious | (reading script) 'The vicar sits'.
| The vicar sits.
Vicar | It's about this letter you sent me regarding my insurance claim.
Devious | Oh, yeah, yeah - well, you see, it's just that we're not...as yet...totally satisfied with the grounds of your claim.
Vicar | But it says something about filling my mouth in with cement.
Devious | Oh well, that's just insurance jargon, you know.
Vicar | But my car was hit by a lorry while standing in the garage and you refuse to pay my claim.
Devious | (rising and crossing to a filing cabinet) Oh well, reverend Morrison...in your policy...in your policy...(he open the drawer of the filing cabinet and takes out a shabby old sports jacket; he feels in the pocket and pulls out a crumbled dog-eared piece of paper then puts the coat back and shuts the filing cabinet)...here we are. It states quite clearly that no claim you make will be paid.
Vicar | Oh dear.
Devious | You see, you unfortunately plumped for our 'Neverpay' policy, which, you know, if you never claim is very worthwhile...but you had to claim, and, well, there it is.
Vicar | Oh dear, oh dear.
Devious | Still, never mind - could be worse. How's the nude lady?
Vicar | Oh, she's fine. (he begins to sob)
Devious | Look...Rev...I hate to see a man cry, so shove off out the office, there's a good chap.
| The vicar goes out sobbing. Cut to outside. Vicar collects a nude lady sitting in a supermarket shopping trolley...and wheels her disconsolately away. Cut back to inside of office. Close-up of Devious. He gets out some files and starts writing. Suddenly a bishop's crook slams down on the desk in front of Devious. He looks up - his eyes register terror. Cut to reverse angle shot from below. The bishop in full mitre and robes.
Bishop | OK, Devious...Don't move!
Devious | The bishop!
| Animated crime-series-type titles, with suitable music: 'C. OF E. FILMS' 'IN ASSOCIATION WITH THE SUNDAY SCHOOLS BOARD' 'PRESENT' 'THE BISHOP' 'STARRING THE REVEREND E. P. NESBITT' 'AND INTRODUCING F. B. GRIMSBY URQHART-WRIGHT AS THE VOICE OF GOD' 'SPECIAL EFFECTS BY THE MODERATOR OF THE CHURCH OF SCOTLAND' 'DIRECTED BY PREBENDARY "CHOPPER" HARRIS' Exterior beautiful English church. Birds singing, a hymn being sung. Suddenly, sound of a high-powered car roaring towards the church. Screech of tires as a huge open-top American car screeches to a halt outside the church. The bishop leaps out. Behind him (as throughout the film) are his four henchmen... vicars with dark glasses. They wear clerical suits and dog collars. They leap out of their car and race up the drive towards the church. As they do so the hymn is heard to come to an end. Sound of people sitting down. Cut to interior of church. Vicar climbing up into pulpit. Cut back to exterior. The bishop and his vicars racing through the doors. Interior of church. Shot of vicar in pulpit.
Vicar | I take as my text for today...
| Cut to bishop and vicars at doorway.
Bishop | The text, vic! Don't say the text!
| Cut back to vicar.
Vicar | Leviticus 3-14. . .
| The pulpit explodes. Vicar disappears in smoke, flying up into the air. Cut to close-up of the bishop. Behind him there is smoke and people rushing about. Sound of people scrambling over pews in panic etc.
Bishop | We was too late. The Reverend Grundy bit the ceiling.
| The end of the bishop's crook suddenly starts flashing. He lifts the flashing end off and it stops. Using it like a telephone receiver, he speaks into the staff.
Bishop | Hello? ... What?... We'll be right over!
| Still of another church exterior. Crash zoom in on door. Cut to interior. A baptism party round the font. An innocent vicar is just testing the water. Pan across to the parents - a couple of shifty crooks - and two godmothers, obviously all-in wrestlers in drag (cauliflower ears etc.). As the vicar takes the baby it starts to tick loudly.
Vicar | And it is for this reason that the Christian Church lays upon you, the godparents, the obligation of seeing this child is brought up in the Christian faith. Therefore, I name this child...
| Cut to door of church. The bishop and vicars rush in.
Bishop | Don't say the kid's name, vic!
| Cut back to vicar.
Vicar | Francesco Luigi...
| Explosion. Cut to close-up of bishop. Smoke and panic as before.
Bishop | We was too late... The Rev. Neuk saw the light.
| Whip pan to interior of yet another church. A wedding. Bride and groom standing in front of a vicar. Cut to door of church. The bishop and vicars burst in.
Bishop | The ring, vic Don't touch the ring! Hey vic!
| Cut to vicar taking the ring out of the bible. The ring is attached to a piece of string. A sixteen-ton weight falls on top of them with a mighty crunch - the camera shakes as it hits the floor. Cut to two bell ringers. One pulls his rope, and the other rises off the floor, hanged by the neck. The bishop arrives, just too late. Cut to another vicar at graveside.
Vicar | ... dust to dust, ashes to ashes.
| He sprinkles dust on the grave. A huge prop cannon rises up out of the grave until its mighty barrel (twelve inches wide) is pointing right in the vicar's face. He does not notice. Sound of car screeching to a halt. We pan away from grave to reveal the bishop leaping out of the car. Sound of an almighty blast from the cannon. The bishop gets back into the car immediately and turns it round. Cut to a street. Outside a cigarette shop the four clerics lounge against a wall. The bishop walks out rolling his own. Suddenly he stops. Close-up. He looks up as he hears a faint cry. Camera swings round and up - enormous zoom to high window in huge, drab city office block, where a vicar is looking out.
Vicar | Help ... help... help... help... help... help...
| Cut back to the bishop breaking into a run, throwing his cigarette into the gutter. Peter Gunn music. Hand-held shots of the bishop and the four vicars running through crowded streets. He reaches the office block, rushes in. Interior: a stair well. Right at the bottom we see the bishop and the vicars. Close-up hand-held shot of bishop running up stairs. Shadows running up the stair well. The bishop arrives on the top landing. Door of office. The bishop tries the door. It won't open. One vicar goes rigid. The other three take hold of him and use him as a battering ram and go straight through the balsa wood door first time.
Bishop | OK, Devious, don't move!
Devious | The bishop!
| 'The Bishop' titles again. Cut to interior of cinema. A couple holding hands. Bishop film titles start up again exactly as before. After a couple of seconds of titles we cut to an old couple sitting in the back row of the cinema facing camera. The sound of the bishop's titles continues. The light from the projector is streaming out above their heads.
Mr Potter | This is where we came in.
Mrs Potter | Yes.
| Cut immediately to the front of the cinema. A working-class lounge is arranged on the pavement. There are no walls, just the furnishings: settee, two armchairs, sideboard, table, standard lamp, a tiled fireplace with ornaments on it. There is also a free-standing inside door. Mr and Mrs Potter come out of the cinema and go straight to their chairs and sit down. Passers-by have to skirt the living-room furniture.
Mrs Potter | (settling into her chair) Oh, it's nice to be home.
Mr Potter | (looking round) Builders haven't been then.
Mrs Potter | No.
| A trendy interviewer with hand mike comes into shot.
Interviewer | These two old people are typical of the housing problem facing Britain's aged.
Mrs Potter | Here! Don't you start doing a documentary on us, young man.
Interviewer | Oh please ...
Mrs Potter | No, you leave us alone!
Interviewer | Oh, just a little one about the appalling conditions under which you live.
Mrs Potter | No! Get out of our house! Go on!
| Interviewer turns, motions to his cameraman and soundman and they all trail off miserably.
Cameraman | Oh all right. Come on, George, pick it up.
Mrs Potter | Why don't you do a documentary about the drug problem round in Walton Street?
| Cut to the camera crew. They stop, turn and mutter 'a drug problem!' and they dash off.
Mrs Potter | Oh, I'll go and have a bath.
| She goes to the free-standing door and opens it. Beyond it we see the furnishings of a bathroom. In the bath is Alfred Lord Tennyson, fully clad. As she opens the door we hear him reciting:
Tennyson | The splendour fans on castle walls And snowy summits old in story...
| She slams the door.
Mrs Potter | 'Ere, there's Alfred Lord Tennyson in the bathroom.
Mr Potter | Well, at least the poet's been installed, then.
| Cut to an officious-looking man in Gas Board type uniform and peaked cap. CAPTION: 'SALES MANAGER EAST MIDLANDS POET BOARD'
Sales Manager | Yes, a poet is essential for complete home comfort, and all-year round reliability at low cost. We in the East Midlands Poet Board hope to have a poet in every home by the end of next year.
| ANIMATION: an advertisement.
Voices | (singing) Poets are both clean and warm And most are far above the norm Whether here, or on the roam Have a poet in every home.
| Cut to middle-class hall. The front doorbell rings. Housewife opens door to Gas Board type inspector with bicycle clips, rubber mac and cap and notebook. In the background we can hear muffled Wordsworth.
Voice | I wandered lonely as a cloud That floats on high...
Inspector | Morning, madam, I've come to read your poet.
She | Oh yes, he's in the cupboard under the stairs.
Inspector | What is it, a Swinburne? Shelley?
She | No, it's a Wordsworth.
Inspector | Oh, bloody daffodils.
| He opens the door of the cupboard under the stairs. Inside is Wordsworth crouching and reciting.
Wordsworth | A host of golden daffodils Beside the lake, beneath the trees Fluttering and dancing in the breeze
| All this while the inspector is shining his torch over him and noting things on his clip board.
Wordsworth | Continuous as the stars that shine And twinkle in the Milky Way They stretch in...
| The inspector shuts the door in the middle of this and we hear Wordsworth reading on, though muffled, throughout the remainder of the sketch.
Inspector | Right. Thank you, madam.
| He makes as if to go, but she seems anxious to detain him and bars his way.
She | Oh, not at all. Thank you... It's a nice day, isn't it?
Inspector | Yes, yes, the weather situation is generally favourable. There's a ridge of high pressure centred over Ireland which is moving steadily eastward bringing cloudy weather to parts of the West Country, Wales and areas west of the Pennines. On tomorrow's chart ... (he reaches up and pulls down a big weather chart from the wall) the picture is much the same. With this occluded front bringing drier, warmer weather. Temperatures about average for the time of year. That's three degrees centigrade, forty-four degrees fahrenheit, so don't forget to wrap up well. That's all from me. Goodnight.
| Cut to BBC world symbol.
Continuity Voice | Now on BBC television a choice of viewing. On BBC 2 - a discussion on censorship between Derek Hart, The Bishop of Woolwich and a nude man. And on BBC 1 - me telling you this. And now...
| Sound of TV set bring switched off. The picture reduces to a spot and we pull out to see that it was actually on a TV set which has just been switched off by the housewife. She and the gas man are now sitting in her living room. He is perched awkwardly on the edge of the sofa. He holds a cup of tea with a cherry on a stick in it.
She | We don't want that, do we. Do you really want that cherry in your tea? Do you like doing this job?
Inspector | Well, it's a living, isn't it?
She | I mean, don't you get bored reading people's poets all day?
Inspector | Well, you know, sometimes ... yeah. Anyway, I think I'd better be going.
| As he gets up she comes quickly to his side.
She | (seductively) You've got a nice torch, haven't you?
Inspector | (looking at it rather baffled) Er, yeah, yeah, it er... it er ... it goes on and off.
| He demonstrates.
She | (drawing closer becoming breathy) How many volts is it?
Inspector | Er ... um... well, I'll have a look at the batteries. (he starts unscrewing the end)
She | Oh yes, yes.
Inspector | It's four and a half volts.
She | (rubbing up against him) Mmmm. That's wonderful. Do you want another look at the poet?
Inspector | No, no, I must be off, really.
She | I've got Thomas Hardy in the bedroom. I'd like you to look at him.
Inspector | Ah well, I can't touch him. He's a novelist.
She | Oh, he keeps mumbling all night.
Inspector | Oh well, novelists do, you see.
She | (dragging him onto the sofa) Oh forget him! What's your name, deary?
Inspector | Harness.
She | No, no! Your first name, silly!
Inspector | Wombat.
She | Oh, Wombat. Wombat Harness! Take me to the place where eternity knows no bounds, where the garden of love encloses us round. Oh Harness!
Inspector | All right, I'll have a quick look at yer Thomas Hardy.
| Cut to studio discussion. CAPTION: 'DEREK HART'
Derek | Nude man, what did you make of that?
Nude Man | Well, don't you see, that was exactly the kind of explicit sexual reference I'm objecting to. It's titillation for the sake of it. A deliberate attempt at cheap sensationalism. I don't care what the so-called avant-garde, left-wing, intellectual namby-pambies say... It is filth!
Derek | Bishop.
| Cut to crook hitting desk in Devious's office.
Bishop | Okay, don't anybody move!
| Titles for 'The Bishop' start and then stop abruptly. CAPTION: 'AN APOLOGY'
Voice Over | The BBC would like to apologize for the constant repetition in this show.
| DIFFERENT CAPTION READING: 'AN APOLOGY'
Voice Over | The BBC would like to apologize for the constant repetition in this show.
| ANIMATION: the 'five frog curse'. Cut to the five Gumbys standing in a tight group.
Gumbys | Thank you. And now a sketch about a chemist called The Chemist Sketch.
| A number of men and women are sitting around in an area by the counter where there is a large sign saying 'Dispensing Department'. A cheerful chemist appears at the counter.
Chemist | (JOHN) Right. I've got some of your prescriptions here. Er, who's got the pox? (nobody reacts) ... Come on, who's got the pox ... come on... (a man timidly puts his hand up) . .. there you go. (throws bottle to the man with his hand up) Who's got a boil on the bum... boil on the botty. (throws bottle to the only man standing up) Who's got the chest rash? (a woman with a large bosom puts up hand) Have to get a bigger bottle. Who's got wind? (throws bottle to a man sitting on his own) Catch.
| CAPTION: 'THE CHEMIST SKETCH - AN APOLOGY'
Voice Over | The BBC would like to apologize for the poor quality of the writing in that sketch. It is not BBC policy to get easy laughs with words like bum, knickers, botty or wee-wees. (laughs off camera) Ssssh!
| Cut to a man standing by a screen with a clicker.
BBC Man | These are the words that are not to be used again on this programme.
| He clicks the clicker. On screen appear the following slides: B*M B*TTY P*X KN*CKERS W**-W** SEMPRINI
| A girl comes into shot.
Girl | Semprini!?
BBC Man | (pointing) Out!
| Cut back to the chemist's shop. The chemist appears again.
Chemist | Right, who's got a boil on his Semprini, then?
| A policeman appears and bundles him off. Cut to another chemist's shop with a different chemist standing at the counter. SUPERIMPOSED CAPTION: 'A LESS NAUGHTY CHEMIST'S' A man walks in.
Man | Good morning.
Chemist | Good morning, sir.
Man | Good morning. I'd like some aftershave, please.
Chemist | Ah, certainly. Walk this way, please.
Man | If I could walk that way I wouldn't need aftershave.
| The policeman runs into the shop and hauls the man off. Cut to shop again. CAPTION: 'A NOT AT ALL NAUGHTY CHEMIST'S' Another chemist is standing with a large sign reading 'A Not At All Naughty Chemist'. Pull back to reveal sign above stock reads 'Not At All Naughty Chemists Ltd'. A man enters.
Man | Good morning.
Chemist | (puts down sign) Good morning, sir. Can I help you?
Man | Yes. I'd like some aftershave.
Chemist | Ah. A toilet requisite-t-t-t-t-t... Would you like to try this, sir. It's our very very latest, it's called Sea Mist.
Man | (sniffs it) I quite like it.
Chemist | How about something a little more musky? This one's called Mimmo.
Man | Not really, no. Have you anything a little more fishier?
Chemist | Fishier?
Man | Fishier.
Chemist | Fish, fish, fish. A fishy requisite-t-t-t-t-t...
Man | Like halibut or sea bass.
Chemist | Or bream?
Man | Yes.
Chemist | No, we haven't got any of that... ah, I've got mackerel... or cod... or hake...
Man | You haven't got anything a little more halibutish?
Chemist | Er... parrot? What's that doing there? Or skate with just a hint of prawn? Or crab, tiger and almonds, very unusual.
Man | I really had my heart set on halibut.
Chemist | Well, sir, we had a fishy consignment in this morning, so I could nip down to the basement and see if I can come up trumps on this particular requisite-t-t-t-t-t. So it was halibut... or... ?
Man | Sea bass.
Chemist | Sea bass. Won't be a moment.
| The man waits for a few seconds, starts becoming uncomfortable, looks at watch, hums.
Man | (to camera) Sorry about this... pom pom pom... Normally we try to avoid these little ... pauses ... longeurs... only dramatically he's gone down to the basement, you see. 'Course, there isn't really a basement but he just goes off and we pretend... Actually what happens is he goes off there, off camera, and just waits there so it looks as though he's gone down ... to the basement. Actually I think he's rather overdoing it. Ah!
| Long shot of the chemist with carton waiting off camera. Floor manager cues him and he walks to counter.
Chemist | Well, sorry, sir. (out of breath) Lot of steps. (man winks at camera) Well, I'm afraid it didn't come in this morning, sir. But we have got some down at our Kensington branch. I'll just nip down there and get it for you.
Man | How long will that be?
Chemist | Twenty minutes.
Man | Twenty minutes!
| As he stands getting embarrassed, a girl hastily dressed as an assistant approaches him and hands him a message on a long stick.
Man | Oh... I wonder what other people use for aftershave lotion?
| Cut to vox pops film.
First Gumby | I use a body rub called Halitosis to make my breath seem sweet.
Second Gumby | I use an aftershave called Semprini.
| He is hauled off by policeman.
Chemist | (hurrying past) I'm sorry, sorry - can't stop now, I've got to get to Kensington.
Cardinal Ximinez | I use two kinds of aftershave lotions - Frankincense, Myrrh - three kinds of aftershave lotions, Frankincense, Myrrh, Sandalwood - four kinds of aftershave lotion. Frankincense, ....
Another Man | I have a cold shower every morning just before I go mad, and then I go mad, 1. Mad, 2. Mad, 3. Mad, 4...
Shabby | I use Rancid Polecat number two. It keeps my skin nice and scaly.
Chemist | (hurrying Past) Sorry again. Can't stop - got to get back.
| Cut back to chemist's where the man is at a clock on wall pushing minute hand round twenty minutes. SUPERIMPOSED CAPTION: '20 MINS LATER' He looks at the camera guiltily and returns to right side of counter. The chemist enters.
Chemist | Well I'm afraid they don't have any at our Kensington branch. But we have some down at the depot.
Man | Where's that?
Chemist | Aberdeen.
Man | Aberdeen?
Chemist | It's all right. Wait here ... I've got a car.
Man | No, no, no. I'll take the other, the crab, tiger and...
Chemist | Almond requisite... t... t... ?
Man | I'll take it.
| The chemist turns his back. A shoplifter enters. There is two men inside a large mac. He has false arms behind his back a la Duke of Edinburgh. The man watches him. He strolls to the counter and then two arms come out of coat and grab things from counter taking them inside the coat. Then these two arms are joined by a third arm which is black. All these arms steal stuff. The man taps the chemist and points at shoplifter. Chemist watches and then blows whistle. They wait for a tick. Then the policeman runs into the shop.
Policeman | Right. Right! RIGHT! Now then! Now then! Your turn.
Chemist | Aren't you going to say 'What's all this then?'?
Policeman | Oh! Right, what's all this, then?
Chemist | This man has been shoplifting, officer.
Policeman | Oh, he has? Yus?
Chemist | Yes.
Policeman | Are you trying to tell me my job?
Chemist | No, but he's been shoplifting.
Policeman | Look! I must warn you that anything you may say will be ignored and furthermore, given half a chance I'll put my fist through your teeth. F'tang. F'tang.
Man | But officer, this man here...
Policeman | I've had enough of you. You're under arrest.
| He makes noises of plane flying and firing.
Chemist | Officer, it wasn't him. (indicates shoplifter) He's the shoplifter.
Shoplifter | No I'm not.
Shoplifter's Mate | (sticking his head out of mac) He's not ... I'm a witnes.
Policeman | (to chemist) One more peep out of you and I'll do you for heresy.
Chemist | Heresy. Blimey. I didn't expect the Spanish Inquisition.
Policeman | Shut up! F'tang. F'tang. Oh, that's nice. (he takes an object off the counter and pockets it) Right. I'm taking you along to the station.
Man | What for?
Policeman | I'm charging you with illegal possession of whatever we happen to have down there. Right. (makes plane noise again) Lunar module calling Buzz Aldrin. Come in. Raindrops keep falling on my head... but that doesn't mean that my...
| CAPTION: 'AN APOLOGY'
Voice Over | The BBC would like to apologize to the police about the character of Police Constable Pan Am. He was not meant to represent the average police officer. Similarly, the reference to Buzz Aldrin, the astronaut, was the product of a disordered mind and should not be construed as having any other significance.
| Photo of Buzz Aldrin.
| SUPERIMPOSED CAPTION: 'THE BUZZ ALDRIN SHOW STARRING BUZZ ALDRIN WITH... (CREDITS)' Cut to Gumbys as at start of show.
Gumbys | And now for something completely different. (jump cut to female Gumbys; then back to original shot) Oh that was fun. And now... CAPTION: 'THE END'
Gumbys | The end. The end! The end! The end!